from .base_lib import BaseLib
from .puzzle import Puzzle
from .kissmanga_com import KissMangaComCrypt
from .manga_rock_com import MangaRockComCrypt
from .manhuagui_com import ManhuaGuiComCrypt
from .sunday_webry_com import SundayWebryCom
from .ac_qq_com import AcQqComCrypt
